==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Сви фонтови</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активно</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Кинаски</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Истог размака</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потврди</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Оштећена датотека</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Иста верзија је инсталирана</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Системски фонт</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Фонтови</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 фонт инсталиран</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 фонтова инсталирано</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Заиста желите да обришете овај фонт?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Овај фонт неће бити доступан програмима</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ови фонтови неће бити доступни програмима</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Осталих %1 системских фонтова се не могу уклонити</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Фонт &quot;%1&quot; се користи и не може се уклонити</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Осталих %1 системких фонтова и фонт &quot;%2&quot; који се користи се не могу уклонити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Заиста желите да обришете %1 фонт/а/ова?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Уклањање фонтова, сачекајте...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Провера фонта</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Нема фонтова за инсталацију</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Не дозволи да твоји снови остану снови</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Основни подаци</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стил</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Врста</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Непознато</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Пуно име</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>П.С. име</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Заштитни знак</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Управник Фонтова</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Управник Фонтова помаже корисницима да инсталирају и управљају са фонтовима.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Учитавање фонтова, сачекајте...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Фонт је извезен на радну површину</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 фонта/ова је извезено на радну површину</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Неуспешан извоз 1 фонта. Недовољно простора на диску.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Неуспешан извоз %1 фонта/ова. Недовољно простора на диску.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Додај фонт</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Омогући</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Онемогући</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Уклони из омиљеног</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Извези</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>деактивирано</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Фонт је деактивиран</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 се користи и не можете га онемогућити</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Не можете онемогућити системке фонтове и фонтеве који се користе</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Не можете онемогућити системске фонтове</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Није дозвољено онемогућити одређене фонтове</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Инсталирај фонт</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Проверавање...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Непознато</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Оштећена датотека</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Инсталиран</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Није инсталиран</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Инсталирај фонт</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Нема резутата претраге</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Нема фонта</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Страница нагоре</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation> Страница надоле</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Додај фонт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Уклони из омиљеног</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Подаци фонта</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Унеси текст за преглед</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Оштећена датотека</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Сви фонтови</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активно</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Кинаски</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Истог размака</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 је породица фонтова, ако нставите, сви фонтови у њој ће бити обрисани</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 је породица фонтова, ако нставите, сви фонтови у њој ће бити омогућени</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 је породица фонтова, ако нставите, сви фонтови у њој ће бити онемогућени</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Омогући</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Онемогући</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Примени на све изабране породице фонтова</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Оштећена датотека</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Иста верзија је инсталирана</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Системски фонт</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 фонт инсталиран</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 фонтова инсталирано</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Неуспешно инсталирање %1 фонта/ова. Недовољно простора на диску.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Овај фонт неће бити доступан програмима</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ови фонтови неће бити доступни програмима</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Осталих %1 системских фонтова се не могу уклонити</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Фонт &quot;%1&quot; се користи и не може се уклонити</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Осталих %1 системких фонтова и фонт &quot;%2&quot; који се користи се не могу уклонити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Заиста желите да обришете %1 фонт/а/ова?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Уклањање фонтова, сачекајте...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Провера фонта</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Нема фонтова за инсталацију</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Изађи</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Настави</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Основни подаци</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стил</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Врста</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Непознато</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Пуно име</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>П.С. име</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Заштитни знак</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Управник Фонтова</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Управник Фонтова помаже корисницима да инсталирају и управљају са фонтовима.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Учитавање фонтова, сачекајте...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Фонт је извезен на радну површину</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 фонта/ова је извезено на радну површину</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Неуспешан извоз 1 фонта. Недовољно простора на диску.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Неуспешан извоз %1 фонта/ова. Недовољно простора на диску.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Додај фонт</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Омогући</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Онемогући</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Уклони из омиљеног</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Извези</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>деактивирано</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Фонт је деактивиран</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 се користи и не можете га онемогућити</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Не можете онемогућити системке фонтове и фонтеве који се користе</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Не можете онемогућити системске фонтове</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Инсталирај фонт</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Проверавање...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Непознато</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Оштећена датотека</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Инсталиран</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Није инсталиран</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Инсталирај фонт</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Нема резутата претраге</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Нема фонта</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Страница нагоре</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation> Страница надоле</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Додај фонт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Уклони из омиљеног</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Подаци фонта</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Унеси текст за преглед</translation>
    </message>
</context>
</TS>
